//zdefiniowac stala XTAL (MHz) w lcd.h, stala F_CPU w delay.h (w Hz)
//zdefiniowac piny i porty wyswietlacza w lcd.h
//zdefiniowac organizacje wyswietlacza w lcd.h
//1-wire: tu dolaczone do PC0, wymagane podciaganie do Vcc przez 4k7 dla pracy parasite powered
//parasite powered mozliwe zdaje sie tylko przy pojedynczym odbiorniku na magistrali 1-wire

#include <stdlib.h>
#include <avr/io.h>
#include <avr/pgmspace.h>
#include "lcd.c"
#include <avr/delay.h>
#include "usart.c"
#include "delay.c"
#include "onewire.h"
#include "ds18x20.c"

#define MAXSENSORS 5
uint8_t gSensorIDs[MAXSENSORS][OW_ROMCODE_SIZE];

uint8_t search_sensors(void)
{
	uint8_t i;
	uint8_t id[OW_ROMCODE_SIZE];
	uint8_t diff, nSensors;
	nSensors = 0;
	
	for( diff = OW_SEARCH_FIRST; 
		diff != OW_LAST_DEVICE && nSensors < MAXSENSORS ; )
	{
		DS18X20_find_sensor( &diff, &id[0] );
		for (i=0;i<OW_ROMCODE_SIZE;i++) gSensorIDs[nSensors][i]=id[i];
		nSensors++;
	}
	return nSensors;
}

//wyswietlenie temperatury na LCD
void put_temp(const uint8_t subzero, uint8_t cel,	uint8_t cel_frac_bits)
{
	uint8_t buffer[sizeof(int)*8+1];
	uint16_t decicelsius;
	uint8_t i;
	decicelsius = DS18X20_temp_to_decicel(subzero, cel, cel_frac_bits);
	lcd_puts((subzero)?"-":"+");
	itoa(decicelsius/10,buffer,10);
	lcd_puts(buffer);
	lcd_puts(".");		//kropka dziesietna
	itoa(decicelsius%10,buffer,10);
	lcd_puts(buffer);
	lcd_putc(0xDF);		//!@#$%jaki to znak: dodac do lcd_puts, znak stopnia
	lcd_puts("C");
}

#ifdef DS18X20_EEPROMSUPPORT
static void eeprom_test(void)
{
//ostroznie, sporo wycieto z oryginalu
    uint8_t sp[DS18X20_SP_SIZE], th, tl;
	uart_puts_P( "\rDS18x20 EEPROM support test for fist sensor\r" ); 
	// DS18X20_recall_E2(&gSensorIDs[0][0]); // already done at power-on
	DS18X20_read_scratchpad( &gSensorIDs[0][0], sp);	
	th = sp[DS18X20_TH_REG];
	tl = sp[DS18X20_TL_REG];
	tl++; th++;
	DS18X20_write_scratchpad( &gSensorIDs[0][0], 
		th, tl, DS18B20_12_BIT);
	DS18X20_copy_scratchpad(  DS18X20_POWER_PARASITE,
		&gSensorIDs[0][0] );
	DS18X20_recall_E2(&gSensorIDs[0][0]);
	DS18X20_read_scratchpad( &gSensorIDs[0][0], sp);
	th = sp[DS18X20_TH_REG];
	tl = sp[DS18X20_TL_REG];
}
#endif



int main(void)
{
    uint8_t nSensors;		//liczba znalezionych na magistrali sensorow
	uint8_t i;
	uint8_t subzero, cel, cel_frac_bits;
	#ifndef OW_ONE_BUS
	ow_set_bus(&PINC,&PORTC,&DDRC,PC0);
	#endif
	nSensors = search_sensors();	//wyszukanie Dallasow
     
    /* initialize display, cursor off */
    lcd_init(LCD_DISP_ON);
	usart_init(USART_BAUDRATE(9600, 4));	//sprytne define makro z usart.h, br = baudrate, fosc = clock frequency in megahertzs

	for (;;)
		{
		if ( nSensors == 1 )		//ten kod zrodlowy ogranicza sie do 1 sensora 
			{
			i = gSensorIDs[0][0]; // family-code for conversion-routine
			DS18X20_start_meas( DS18X20_POWER_PARASITE, NULL );
			delay_ms(DS18B20_TCONV_12BIT);
			DS18X20_read_meas_single(i, &subzero, &cel, &cel_frac_bits);
			lcd_clrscr();
			lcd_puts("Temp:\n");
			put_temp(subzero, cel, cel_frac_bits);
			}
		else
			{
			lcd_clrscr();
			lcd_puts("Sens Err\n");
			}
		}
}